============
Graph butler
============
A small framework for generating simple, reproducible graphs.

Status
======
This project is in an experimental stage and there are some missing
features. Feel free to open an issue
`on Github <https://github.com/jacwah/graphbutler/issues>`_ and I'll get back
to you in a couple of days!
